﻿/*
  Antenna House PDF Tool API V6.0
  .Net Interface sample program

  概要：注釈の付いたPDFのマークアップ注釈を指定したPDFにインポートします。
  　　　その後、インポート済みのPDFを指定した名前で出力します。

  Copyright (C) 2018- Antenna House, Inc. All rights reserved.
  Antenna House is a trademark of [Antenna House, Inc.]

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

using PdfTkNet;
using System;

namespace cookbook
{
    public class ImportAnnotsFromPDF
    {
        // そのクラスのusageを表示する関数
        private static void printUsage()
        {
            Console.Write("usage: ImportAnnotsFromPDF in-pdf-file");
            Console.WriteLine(" out-pdf-file pdf-file-to-import");
        }

        public static void Main(String[] args)
        {
            if (args.Length < 3)
            {
                printUsage();
                return;
            }

            // コマンドライン引数の取得
            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlParamInput PdfToImport = new PtlParamInput(args[2]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                using (PtlPDFDocument docOfImportPDF = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);
                    using (PtlPages pages = doc.getPages()) //ページコンテナの取得
                    {
                     // ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空\n");
                            return;
                        }
                    }

                    // インポート元のPDFファイルが空でないことを確認します。
                    docOfImportPDF.load(PdfToImport);
                    using (PtlPages pages = docOfImportPDF.getPages())  //ページコンテナの取得
                    {
                     // ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空\n");
                            return;
                        }
                    }
                    // PDFファイルから注釈をインポートする
                    doc.importAnnotsFromPDF(PdfToImport);

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine("PtlException : ErrorCode = " + pex.getErrorCode() +
                                   "\n  " + pex.getErrorMessage());
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                Console.WriteLine(ex.StackTrace);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

    }
}
